- path
character path to the shiny app. Default: "."
- fields
character vector listing the types of dependencies, a subset of c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances").
Character string "all" is shorthand for that vector, character string "most" for the same vector without "Enhances", character string "strong" (default) for the first three elements of that vector.
Default: c("Depends", "Imports", "LinkingTo")
- lib.loc
character vector of search paths with local packages. Default: .libPaths()
- local
logical if to use local repository (or newest remote packages). Default: TRUE
- base
logical if to add base packages too. If TRUE then pacs::pacs_base() are taken into account. Default: FALSE
- description_v
logical if the dependencies version should be taken from description files, minimal required. By default installed versions are taken. Default: FALSE
- recursive
logical if to assess the dependencies recursively. Default: TRUE
- repos
character vector base URLs of the repositories to use. By default checking CRAN and newest Bioconductor per R version. Default pacs::biocran_repos()