Learn R Programming

pacs (version 0.6.0)

biocran_repos: CRAN and Bioconductor repositories

Description

CRAN and Bioconductor repositories. The newest Bioconductor release for the specific R version is assumed.

Usage

biocran_repos(version = NULL)

Value

named character vector of repositories.

Arguments

version

character the Bioconductor release. By default the newest Bioconductor release for the specific R version is assumed, if not available only CRAN repository is returned. Available Bioconductor versions for your R version could be checked with pacs::bio_releases(). Default NULL

Examples

Run this code
if (FALSE) {
pacs::biocran_repos()
}

Run the code above in your browser using DataLab