powered by
using the remote github CRAN mirror to compare NEWS files between specific packages versions.
pac_compare_news( pac, old = NULL, new = NULL, lib.loc = .libPaths(), repos = "https://cran.rstudio.com/" )
character with NEWS content between specific versions.
character
character a package name.
character an old version of package, default local version. Default: NULL
NULL
character a new version of package, default newest version. Default: NULL
character vector of search paths with local packages. Default: .libPaths()
.libPaths()
character vector repositories URLs to use. Used only for the validation. Default https://cran.rstudio.com/
https://cran.rstudio.com/
if (FALSE) { pacs::pac_compare_news("shiny", "1.0.0", "1.6.0") # local version to newest one pacs::pac_compare_news("shiny") }
Run the code above in your browser using DataLab