Learn R Programming

pacs (version 0.6.0)

pac_checkred: Checking the R CRAN package check page status

Description

using package R CRAN check page to validate if there are ANY errors and/or fails and/or warnings and/or notes.

Usage

pac_checkred(pac, scope = c("ERROR", "FAIL"), flavors = NULL)

Value

logical if the package fail under specified criteria.

Arguments

pac

character a package name.

scope

character vector scope of the check, accepted values c("ERROR", "FAIL", "WARN", "NOTE"). Default: c("ERROR", "FAIL")

flavors

character vector of CRAN server names to consider, possible names could be get with pacs::cran_flavors()$Flavor. The pacs::match_flavors() function could be used to get CRAN server names matched for your local OS. By default all CRAN machines are considered NULL value. Default: NULL

Examples

Run this code
if (FALSE) {
pacs::pac_checkred("dplyr")
pacs::pac_checkred("dplyr", scope = c("ERROR"))
pacs::pac_checkred("dplyr",
  scope = c("ERROR", "FAIL", "WARN"),
  flavors = pacs::match_flavors()
)
}

Run the code above in your browser using DataLab