logical if the package fail under specified criteria.
Arguments
pac
character a package name.
scope
character vector scope of the check, accepted values c("ERROR", "FAIL", "WARN", "NOTE"). Default: c("ERROR", "FAIL")
flavors
character vector of CRAN server names to consider, possible names could be get with pacs::cran_flavors()$Flavor.
The pacs::match_flavors() function could be used to get CRAN server names matched for your local OS.
By default all CRAN machines are considered NULL value. Default: NULL