- pac
character a package name.
- version
character version of a package. Default: NULL
- at
Date from which to take the version. Default: NULL
- limit
numeric at least days to treat as healthy, ">=limit". Default: 14
- scope
character vector scope of the check, accepted values c("ERROR", "FAIL", "WARN", "NOTE"). Default: c("ERROR", "FAIL")
- flavors
character vector of CRAN server names to consider, possible names could be get with pacs::cran_flavors()$Flavor.
The pacs::match_flavors() function could be used to get CRAN server names matched for your local OS.
By default all CRAN machines are considered NULL value. Default: NULL
- lib.loc
character vector of search paths with local packages. Default: .libPaths()
- repos
character vector repositories URLs to use. Default https://cran.rstudio.com/
- source
character one of c("cran", "crandb").
Using the MEATCRAN CRANDB or the direct web page download from CRAN.
When "crandb" is set then options(pacs.crandb_ntry = 3) and options(pacs.crandb_nsleep = 0.001) can be used to control the fetch.
"pacs.crandb_ntry" can be used to set the maximum number of try outs, by default 3.
"pacs.crandb_nsleep" can be used to set the sleep duration between fetch try outs, by default 0.001.
Default: "cran"