powered by
checking if a package version is the most recent one, by default the installed version is compared.
pac_islast(pac, version = NULL, lib.loc = .libPaths(), repos = biocran_repos())
logical if a package is inside repositories.
logical
character a package name.
character
character version of a package. Default: NULL
NULL
character vector of search paths with local packages. Default: .libPaths()
.libPaths()
character vector of repositories URLs to use. By default checking CRAN and newest Bioconductor per R version. Default pacs::biocran_repos()
pacs::biocran_repos()
if (FALSE) { pac_islast("memoise") pac_islast("dplyr", version = "1.0.0") pac_islast("S4Vectors") pac_islast("S4Vectors", version = pac_last("S4Vectors")) }
Run the code above in your browser using DataLab